
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

from distutils.core import Extension
from distutils.util import get_platform
from distutils.dist import Distribution
import re

doc_files = [r'/Users/kasper/Development/SimpleElastix/LICENSE',r'/Users/kasper/Development/SimpleElastix/NOTICE',r'/Users/kasper/Development/SimpleElastix/README.md',r'/Users/kasper/Development/build/SimpleElastix/SimpleITK-build/ITK-4.8-NOTICE',r'/Users/kasper/Development/build/SimpleElastix/SimpleITK-build/ITK-4.8-README.txt']

def get_pep386version():
    """This method examines the SimpleITK's CMake version variables to make a pep 386 compliant version string when building a version indented for distribution."""
    sitkMAJOR = "0"
    sitkMINOR = "9"
    sitkPATCH = "1"
    sitkTWEAK = "7"
    sitkRC    = ""
    sitkPOST   = ""
    sitkDEV    = ""
    sitkHASH   = "#"


    version = sitkMAJOR+"."+sitkMINOR

    if sitkPATCH:
        version += "."+sitkPATCH
        if sitkTWEAK:
            version += "."+sitkTWEAK

    if  sitkRC:
        version += sitkRC

    if sitkPOST:
        version += ".post"+sitkPOST
    elif sitkDEV:
        version += ".dev"+sitkDEV

    if sitkHASH and not "ON":
        version += "-g"+sitkHASH

    return version


# HACK
# We are using the "data_files" parameter to package up the SimpleITK
# libraries. However distribute does not detect this as an extension
# and does not build a egg with the platform name in the egg file
# name. So we forcable overload a method so that distutils, always
# reports that we are always an extension.
def always_has_ext_modules (self):
    """Always returns true, to force extensimon behavior in packaging."""
    return True
Distribution.has_ext_modules =  always_has_ext_modules



setup(
    name = 'SimpleElastix',
    version = get_pep386version(),
    author = 'Kasper Marstal',
    author_email = 'kaspermarstal@gmail.com',
    packages= ['SimpleElastix'],
    package_dir = {'SimpleElastix':r'/Users/kasper/Development/build/SimpleElastix/SimpleITK-build/Wrapping'},
    #package_data = {'SimpleElastix':[r'_SimpleITK.so']},
    download_url = r'https://github.com/kaspermarstal/SimpleElastix',
    platforms = [],
    description = r'User-friendly medical image registration library',
    long_description  = 'SimpleElastix is an extension of SimpleITK that allow you to use Elastix as a native Python library. Elastix is a modular collection of robust C++ image registration algorithms that is widely used in the literature. This makes state-of-the-art medical image registration easy to do in Python.',
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Scientific/Engineering"
        ],
    license='Apache',
    keywords = 'elastix medical image registration',
    url = r'http://simpleelastix.github.io/'
    )
